#[non_exhaustive]pub enum DeserializeError {
InvalidMagic,
InvalidSeparator,
NoMorePairs,
DecodeGlobal(DecodeError),
DecodeInput(DecodeError),
DecodeOutput(DecodeError),
}Expand description
Error while deserializing a PSBT.
This error is returned when deserializing a complete PSBT, not for deserializing parts of it or individual data types.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMagic
Invalid magic bytes, expected the ASCII for “psbt” serialized in most significant byte order.
InvalidSeparator
The separator for a PSBT must be 0xff.
NoMorePairs
Signals that there are no more key-value pairs in a key-value map.
DecodeGlobal(DecodeError)
Error decoding the global map.
DecodeInput(DecodeError)
Error decoding an input map.
DecodeOutput(DecodeError)
Error decoding an output map.