Constructor

Struct Constructor 

pub struct Constructor<T>(/* private fields */);
Implements the BIP-370 Constructor role.

Uses the builder pattern, and generics to make adding inputs and outputs infallible.

Implementations

Source

impl<T: Mod> Constructor<T>

pub fn no_more_inputs(self) -> Self

Marks that the Psbt can not have any more inputs added to it.

pub fn no_more_outputs(self) -> Self

Marks that the Psbt can not have any more outputs added to it.

pub fn updater(self) -> Result<Updater, DetermineLockTimeError>

Returns a PSBT Updater once construction is completed.

pub fn psbt(self) -> Result<Psbt, DetermineLockTimeError>

Returns the Psbt in its current state.

This function can be used either to get the Psbt to pass to another constructor or to get the Psbt ready for update if no_more_inputs and no_more_outputs have already explicitly been called.

Source

impl Constructor<Modifiable>

pub fn new(psbt: Psbt) -> Result<Self, PsbtNotModifiableError>

Creates a new Constructor.

This function should only be needed if the PSBT Creator and Constructor roles are being performed by separate entities, if not use one of the builder functions on the Creator e.g., constructor_modifiable().

pub fn input(self, input: Input) -> Self

Adds an input to the PSBT.

pub fn output(self, output: Output) -> Self

Adds an output to the PSBT.

Source

impl Constructor<InputsOnlyModifiable>

pub fn new(psbt: Psbt) -> Result<Self, InputsNotModifiableError>

Creates a new Constructor.

This function should only be needed if the PSBT Creator and Constructor roles are being performed by separate entities, if not use one of the builder functions on the Creator e.g., constructor_modifiable().

pub fn input(self, input: Input) -> Self

Adds an input to the PSBT.

Source

impl Constructor<OutputsOnlyModifiable>

pub fn new(psbt: Psbt) -> Result<Self, OutputsNotModifiableError>

Creates a new Constructor.

This function should only be needed if the PSBT Creator and Constructor roles are being performed by separate entities, if not use one of the builder functions on the Creator e.g., constructor_modifiable().

pub fn output(self, output: Output) -> Self

Adds an output to the PSBT.