Extractor

Struct Extractor 

pub struct Extractor(/* private fields */);
Implements the BIP-370 Finalized role.

Implementations

Source

impl Extractor

pub fn new(psbt: Psbt) -> Result<Self, ExtractError>

Creates an Extractor.

An extractor can only accept a PSBT that has been finalized.

pub fn id(&self) -> Txid

Returns this PSBT’s unique identification.

Source

impl Extractor

pub const DEFAULT_MAX_FEE_RATE: FeeRate

The default max_fee_rate value used for extracting transactions with Self::extract_tx.

As of 2023, even the biggest overpayers during the highest fee markets only paid around 1000 sats/vByte. 25k sats/vByte is obviously a mistake at this point.

pub fn extract_tx(&self) -> Result<Transaction, ExtractTxFeeRateError>

pub fn extract_tx_fee_rate_limit( &self, ) -> Result<Transaction, ExtractTxFeeRateError>

Extracts the Transaction from a Psbt by filling in the available signature information.

Errors

ExtractTxError variants will contain either the Psbt itself or the Transaction that was extracted. These can be extracted from the Errors in order to recover. See the error documentation for info on the variants. In general, it covers large fees.

pub fn extract_tx_with_fee_rate_limit( &self, max_fee_rate: FeeRate, ) -> Result<Transaction, ExtractTxFeeRateError>

Extracts the Transaction from a Psbt by filling in the available signature information.

pub fn extract_tx_unchecked_fee_rate( &self, ) -> Result<Transaction, ExtractTxError>

Perform Self::extract_tx_fee_rate_limit without the fee rate check.

This can result in a transaction with absurdly high fees. Use with caution.