InputBuilder

Struct InputBuilder 

pub struct InputBuilder(/* private fields */);
Enables building an Input using the standard builder pattern.

Implementations

Source

impl InputBuilder

pub fn new(previous_output: &OutPoint) -> Self

Creates a new builder that can be used to build an Input that spends previous_output.

pub fn minimum_required_time_based_lock_time(self, lock: Time) -> Self

Sets the Input::min_time field.

pub fn minimum_required_height_based_lock_time(self, lock: Height) -> Self

Sets the Input::min_height field.

pub fn segwit_fund(self, utxo: TxOut) -> Self

Funds this input with a segwit UTXO.

pub fn legacy_fund(self, tx: Transaction) -> Self

Funds this input with a legacy UTXO.

Caller to guarantee that this tx is correct for this input (i.e., has a txid equal to self.previous_txid).

pub fn build(self) -> Input

Builds the Input.