pub struct Output {
pub amount: Amount,
pub script_pubkey: ScriptBuf,
pub redeem_script: Option<ScriptBuf>,
pub witness_script: Option<ScriptBuf>,
pub bip32_derivations: BTreeMap<PublicKey, KeySource>,
pub tap_internal_key: Option<XOnlyPublicKey>,
pub tap_tree: Option<TapTree>,
pub tap_key_origins: BTreeMap<XOnlyPublicKey, (Vec<TapLeafHash>, KeySource)>,
pub sp_v0_info: Option<Vec<u8>>,
pub sp_v0_label: Option<u32>,
pub proprietaries: BTreeMap<ProprietaryKey, Vec<u8>>,
pub unknowns: BTreeMap<Key, Vec<u8>>,
}Expand description
A key-value map for an output of the corresponding index in the unsigned transaction.
Fields
amount: AmountThe output’s amount (serialized as satoshis).
script_pubkey: ScriptBufThe script for this output, also known as the scriptPubKey.
redeem_script: Option<ScriptBuf>The redeem script for this output.
witness_script: Option<ScriptBuf>The witness script for this output.
bip32_derivations: BTreeMap<PublicKey, KeySource>A map from public keys needed to spend this output to their corresponding master key fingerprints and derivation paths.
tap_internal_key: Option<XOnlyPublicKey>The internal pubkey.
tap_tree: Option<TapTree>Taproot Output tree.
tap_key_origins: BTreeMap<XOnlyPublicKey, (Vec<TapLeafHash>, KeySource)>Map of tap root x only keys to origin info and leaf hashes contained in it.
sp_v0_info: Option<Vec<u8>>BIP-375: Silent payment v0 address info (66 bytes: scan_key || spend_key).
sp_v0_label: Option<u32>BIP-375: Silent payment v0 label (4-byte little-endian u32).
proprietaries: BTreeMap<ProprietaryKey, Vec<u8>>Proprietary key-value pairs for this output.
unknowns: BTreeMap<Key, Vec<u8>>Unknown key-value pairs for this output.
Implementations