#[non_exhaustive]pub enum SignerChecksError {
NonWitnessSig,
NonWitnessUtxoTxidMismatch,
WitnessAndNonWitnessUtxo,
RedeemScriptMismatch,
MissingTxOut,
WitnessScriptMismatchWsh,
WitnessScriptMismatchShWsh,
}Expand description
Errors encountered while doing the signer checks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonWitnessSig
Witness input will produce a non-witness signature.
NonWitnessUtxoTxidMismatch
Non-witness input has a mismatch between the txid and prevout txid.
WitnessAndNonWitnessUtxo
Input has both witness and non-witness utxos.
RedeemScriptMismatch
Redeem script hash did not match the hash in the script_pubkey.
MissingTxOut
Missing witness_utxo.
WitnessScriptMismatchWsh
Native segwit p2wsh script_pubkey did not match witness script hash.
WitnessScriptMismatchShWsh
Nested segwit p2wsh script_pubkey did not match redeem script hash.