pub struct Constructor<T>(/* private fields */);Expand description
Implements the BIP-370 Constructor role.
Uses the builder pattern, and generics to make adding inputs and outputs infallible.
Implementations
Sourceimpl<T: Mod> Constructor<T>
impl<T: Mod> Constructor<T>
Sourcepub fn no_more_inputs(self) -> Self
pub fn no_more_inputs(self) -> Self
Marks that the Psbt can not have any more inputs added to it.
Sourcepub fn no_more_outputs(self) -> Self
pub fn no_more_outputs(self) -> Self
Marks that the Psbt can not have any more outputs added to it.
Sourceimpl Constructor<Modifiable>
impl Constructor<Modifiable>
Sourcepub fn new(psbt: Psbt) -> Result<Self, PsbtNotModifiableError>
pub fn new(psbt: Psbt) -> Result<Self, PsbtNotModifiableError>
Creates a new Constructor.
This function should only be needed if the PSBT Creator and Constructor roles are being
performed by separate entities, if not use one of the builder functions on the Creator
e.g., constructor_modifiable().
Sourceimpl Constructor<InputsOnlyModifiable>
impl Constructor<InputsOnlyModifiable>
Sourcepub fn new(psbt: Psbt) -> Result<Self, InputsNotModifiableError>
pub fn new(psbt: Psbt) -> Result<Self, InputsNotModifiableError>
Creates a new Constructor.
This function should only be needed if the PSBT Creator and Constructor roles are being
performed by separate entities, if not use one of the builder functions on the Creator
e.g., constructor_modifiable().
Sourceimpl Constructor<OutputsOnlyModifiable>
impl Constructor<OutputsOnlyModifiable>
Sourcepub fn new(psbt: Psbt) -> Result<Self, OutputsNotModifiableError>
pub fn new(psbt: Psbt) -> Result<Self, OutputsNotModifiableError>
Creates a new Constructor.
This function should only be needed if the PSBT Creator and Constructor roles are being
performed by separate entities, if not use one of the builder functions on the Creator
e.g., constructor_modifiable().